@@ -135,7 +135,7 @@ public class CairoContextEx : Cairo.Context
 		the device unit space and then translate to our user space.
 
 		* Cairo Show.Text paints on the bottom-left of the coordinates
-		and Pango paints on the top-left of the coordinate
+		and Pango paints on the top-left of the coordinates
 	*/
 
 
@@ -348,5 +348,41 @@ public class CairoContextEx : Cairo.Context
 		}
 	}
 
+	public void DrawImageFromAssembly (string  resource, double x, double y, double width, double height)
+	{
+		try {
+			using (SVGImage image = new SVGImage (System.Reflection.Assembly.GetCallingAssembly (), resource))
+			{
+				DrawImage (image, x, y, width, height);
+			}
+		}
+		catch (Exception)
+		{
+			return;
+		}
+	}
+
+	public void DrawImageFromFile (string filename, double x, double y, double width, double height)
+	{
+		try {
+			using (SVGImage image = new SVGImage (filename))
+			{
+				DrawImage (image, x, y, width, height);
+			}
+		}
+		catch (Exception)
+		{
+			return;
+		}
+	}
+
+	void DrawImage (SVGImage image, double x, double y, double width, double height)
+	{		
+		Save ();
+		Translate (x, y);
+		Scale (width / image.Width, height / image.Height);
+		image.RenderToCairo (Handle);
+		Restore ();
+	}
 }
 
