@@ -24,6 +24,7 @@ using System.Timers;
 
 public class GameSession
 {
+	[Flags]
 	public enum Types
 	{	
 		None			= 0,
@@ -71,11 +72,6 @@ public class GameSession
 	{
 		game_manager = new GameManager ();
 		game_time = TimeSpan.Zero;
-		games_played = 0;
-		games_won = 0;
-		current_game = null;
-		timer = null;
-		paused = false;
 		app = brainy;
 
 		timer = new System.Timers.Timer ();
@@ -84,8 +80,6 @@ public class GameSession
 		
 		scores = new int [(int) ScoresType.Last];
 		games = new int [(int) ScoresType.Last];
-		total_score = 0;
-		scored_game = false;
 		status = SessionStatus.NotPlaying;
 	}
 
@@ -286,7 +280,7 @@ public class GameSession
 
 	public void ScoreGame ()
 	{
-		if (scored_game == true)
+		if (current_game == null || scored_game == true)
 			return;
 
 		switch (current_game.Type) {
@@ -325,7 +319,7 @@ public class GameSession
 		Application.Invoke (delegate {	app.UpdateStatusBar (); } );
 	}
 
-	private string TimeSpanToStr (TimeSpan time)
+	static private string TimeSpanToStr (TimeSpan time)
 	{
 		string fmt = time.ToString ();
 		int i = fmt.IndexOf ('.');
@@ -334,7 +328,5 @@ public class GameSession
 
 		return fmt;
 	}
-
-
 }
 
