@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Jordi Mas i Hernàndez <jmas@softcatala.org>
+ * Copyright (C) 2008-2009 Jordi Mas i Hernàndez <jmas@softcatala.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -40,8 +40,11 @@ public class SVGImage : IDisposable
 	[DllImport("rsvg-2")]
 	static extern void rsvg_handle_get_dimensions (IntPtr handle, ref RsvgDimensionData dimension);
 
+	[DllImport("rsvg-2")]
+	static extern IntPtr rsvg_handle_new_from_data (byte[] data, int len, out int error);
+
 	[StructLayout(LayoutKind.Sequential)]
-	protected struct RsvgDimensionData
+	struct RsvgDimensionData
 	{
 	    	public int width;
 	    	public int height;
@@ -49,8 +52,30 @@ public class SVGImage : IDisposable
 		public double ex;
 	}
 
-	private RsvgDimensionData dimension;
-	private IntPtr handle;
+	RsvgDimensionData dimension;
+	IntPtr handle;
+
+	public SVGImage (System.Reflection.Assembly _assembly, string resource)
+	{
+		try {
+			byte[] array;
+			Stream stream;
+			int error = 0;
+
+			stream =  _assembly.GetManifestResourceStream (resource);
+			array = new byte [stream.Length];
+
+			stream.Read (array, 0, (int) stream.Length);
+			
+			handle = rsvg_handle_new_from_data (array, array.Length, out error);
+			rsvg_handle_get_dimensions (handle, ref dimension);
+		} 
+		finally
+		{
+			if (handle == IntPtr.Zero)
+				throw new System.IO.IOException ("Resource not found: " + resource);
+		}
+	}
 	
 	public SVGImage (string file)
 	{
@@ -81,13 +106,24 @@ public class SVGImage : IDisposable
 		get { return dimension.height; }
 	}
 
+	~SVGImage ()
+	{
+		Dispose (false);
+	}
+
 	public void Dispose ()
+	{
+		Dispose (true);
+		System.GC.SuppressFinalize (this);
+	}
+
+	protected virtual void Dispose (bool disposing)
 	{
 		if (handle == IntPtr.Zero)
 			return;
 
 		rsvg_handle_free (handle);
-		handle = IntPtr.Zero;	
+		handle = IntPtr.Zero;
 	}
 
 	public void RenderToCairo (IntPtr cairo_surface)
@@ -96,4 +132,3 @@ public class SVGImage : IDisposable
 			rsvg_handle_render_cairo (handle, cairo_surface);
 	}
 }
-
